package jdk.management.resource.internal.inst;

import jdk.internal.instrumentation.Logger;
import java.security.AccessController;
import java.util.PropertyPermission;
import java.security.Permission;
import sun.security.action.GetPropertyAction;
import java.util.Arrays;
import jdk.internal.instrumentation.Tracer;

public final class InitInstrumentation implements Runnable
{
    volatile boolean initialized;
    static final Class<?>[] hooks;
    
    public InitInstrumentation() {
        this.initialized = false;
    }
    
    @Override
    public synchronized void run() {
        if (!this.initialized) {
            try {
                Tracer.getInstance().addInstrumentations(Arrays.asList(InitInstrumentation.hooks), InitInstrumentation.TestLogger.tlogger);
            }
            catch (ClassNotFoundException ex) {
                InitInstrumentation.TestLogger.tlogger.error("Unable to load class: " + ex.getMessage(), ex);
            }
            catch (Exception ex2) {
                InitInstrumentation.TestLogger.tlogger.error("Unable to load class: " + ex2.getMessage(), ex2);
            }
            this.initialized = true;
        }
    }
    
    static {
        Class[] array = { AbstractInterruptibleChannelRMHooks.class, AbstractPlainDatagramSocketImplRMHooks.class, AbstractPlainSocketImplRMHooks.class, AsynchronousServerSocketChannelImplRMHooks.class, AsynchronousSocketChannelImplRMHooks.class, BaseSSLSocketImplRMHooks.class, DatagramChannelImplRMHooks.class, DatagramDispatcherRMHooks.class, DatagramSocketRMHooks.class, FileChannelImplRMHooks.class, FileInputStreamRMHooks.class, FileOutputStreamRMHooks.class, NetRMHooks.class, RandomAccessFileRMHooks.class, ServerSocketRMHooks.class, ServerSocketChannelImplRMHooks.class, SocketChannelImplRMHooks.class, SocketDispatcherRMHooks.class, SocketInputStreamRMHooks.class, SocketOutputStreamRMHooks.class, SocketRMHooks.class, SSLSocketImplRMHooks.class, SSLServerSocketImplRMHooks.class, ThreadRMHooks.class, WrapInstrumentationRMHooks.class };
        Class[] array2;
        if (((String)AccessController.doPrivileged(new GetPropertyAction("os.name"), null, new Permission[] { new PropertyPermission("os.name", "read") })).startsWith("Windows")) {
            array2 = new Class[] { WindowsAsynchronousFileChannelImplRMHooks.class, WindowsAsynchronousServerSocketChannelImplRMHooks.class, WindowsAsynchronousSocketChannelImplRMHooks.class };
        }
        else {
            array2 = new Class[] { SimpleAsynchronousFileChannelImplRMHooks.class, UnixAsynchronousServerSocketChannelImplRMHooks.class, UnixAsynchronousSocketChannelImplRMHooks.class };
        }
        System.arraycopy(array, 0, hooks = new Class[array.length + array2.length], 0, array.length);
        System.arraycopy(array2, 0, InitInstrumentation.hooks, array.length, array2.length);
    }
    
    static class TestLogger implements Logger
    {
        static final InitInstrumentation.TestLogger tlogger;
        
        public void debug(String s) {
            System.out.printf("TestLogger debug: %s%n", new Object[] { s });
        }
        
        public void error(String s) {
            System.out.printf("TestLogger error: %s%n", new Object[] { s });
        }
        
        public void error(String s, Throwable t) {
            System.out.printf("TestLogger error: %s, ex: %s%n", new Object[] { s, t });
            t.printStackTrace();
        }
        
        public void info(String s) {
            System.out.printf("TestLogger info: %s%n", new Object[] { s });
        }
        
        public void trace(String s) {
        }
        
        public void warn(String s) {
            System.out.printf("TestLogger warning: %s%n", new Object[] { s });
        }
        
        static {
            tlogger = new InitInstrumentation.TestLogger();
        }
    }
}
